#define HAVE_GETGROUPLIST 0

/* Defined if system has POSIX ACL support. */
#define HAVE_POSIX_ACL 1
/* Defined if acl/libacl.h exists */
#define HAVE_ACL_LIBACL_H 1
/* Defined if sys/extattr.h exists */
#define HAVE_SYS_EXTATTR_H 0
/* Defined if sys/mount.h exists */
#define HAVE_SYS_MOUNT_H 1
/* Defined if sys/stat.h exists */
#define HAVE_SYS_STAT_H 0
/* Defined if sys/xattr.h exists */
#define HAVE_SYS_XATTR_H 1
/* Defined if has Wayland support */
#define HAVE_WAYLAND 1
